@@ -167,9 +167,8 @@
 			var options = {
 				mode: 'normal',
 				territory: territory || 'FXX',
-				projection: projection || 'IGNF:GEOPORTALFXX',
-				displayProjection: displayProjection || 'IGNF:RGF93G',
-				proxy: 'http://api.ign.fr/geoportail/api/xmlproxy?url='
+				projection: projection || null,
+				displayProjection: displayProjection || 'IGNF:RGF93G'
 			};
 
 			var target_id;
@@ -186,6 +185,7 @@
 			));
 			viewer.addGeoportalLayers(['ORTHOIMAGERY.ORTHOPHOTOS',
 			                           'GEOGRAPHICALGRIDSYSTEMS.MAPS'], {});
+			viewer.map.getLayersByName('GEOGRAPHICALGRIDSYSTEMS.MAPS')[0].setOpacity(0.8);
 
 			var target = $(target).get(0);
 			$.data(target, 'ztfy.geoportal.viewer', viewer);
